#
# spec file for package libclc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libclc
Version:        0.2.0+git.20171127
Release:        lp150.1.5
Summary:        OpenCL C programming language library
License:        BSD-3-Clause OR MIT
Group:          Development/Libraries/C and C++
Url:            http://libclc.llvm.org/
Source0:        %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRequires:  gcc
BuildRequires:  libstdc++-devel >= 3.9
BuildRequires:  llvm >= 4.0
BuildRequires:  llvm-clang-devel >= 4.0
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  zlib-devel

%description
Library requirements of the OpenCL C programming language.

%prep
%setup -q

%build
sed -i "s|python|python3|g" configure.py
export \
  CFLAGS="%{optflags}" \
  CXXFLAGS="%{optflags}" \
  CC=clang \
  CXX=clang++
python3 ./configure.py \
  --prefix=%{_prefix} \
  --with-llvm-config=%{_bindir}/llvm-config \
  --with-cxx-compiler=${CXX} \
  --enable-runtime-subnormal \
  --pkgconfigdir=%{_libdir}/pkgconfig/ \
  --libexecdir=%{_libdir}/clc/
make %{?_smp_mflags} VERBOSE=1

%install
%make_install

%files
%doc LICENSE.TXT
%{_includedir}/clc
%{_libdir}/clc
%{_libdir}/pkgconfig/libclc.pc

%changelog
* Sat Dec 23 2017 mpluskal@suse.com
- Update to version 0.2.0+git.20171127:
  * configure.py: Add gfx900 (Vega, Raven)
  * math: Implement minmag
  * math: Implement maxmag
  * native_powr: Switch implementation to native_exp2 and native_log2
  * native_divide: provide function implementation instead of macro
  * native_recip: provide function implementation instead of macro
  * native_rsqrt: Switch implementation to 1 / native_sqrt
  * native_tan: Switch implementation to use native_sin/native_cos
  * math: Use precomputed constant for log2(10.0)
  * native_exp10: Switch implementation to llvm intrinsic
  * native_sqrt: Switch implementation to llvm intrinsic
  * native_sin: Switch implementation to llvm intrinsic
  * native_cos: Switch implementation to llvm intrinsic
  * native_exp2: Switch implementation to llvm intrinsic
  * native_exp: Switch implementation to llvm intrinsic
  * amdgpu: Add workaround for unimplemented llvm.exp intrinsic
  * native_log10: Switch to generic native intrinsic inc file
  * native_log: Switch to generic native intrinsic inc file
  * native_log2: Switch to generic native intrinsic inc file
* Tue Nov  7 2017 mpluskal@suse.com
- Update to version 0.2.0+git.20171102:
  * tgamma: Use unary_decl instead of custom inc file
  * tanh: Use unary_decl instead of custom inc file
  * tan: Use unary_decl instead of custom inc file
  * sqrt: Use unary_decl instead of custom inc file
  * sinpi: Use unary_decl instead of custom inc file
  * sinh: Use unary_decl instead of custom inc file
  * sin: Use unary_decl instead of custom inc file
  * native_log: Use unary_decl instead of custom inc file
  * native_log2: Use unary_decl instead of custom inc file
  * native_log10: Use unary_decl instead of custom inc file
  * log: Use unary_decl instead of custom inc file
  * logb: Use unary_decl instead of custom inc file
  * log2: Use unary_decl instead of custom inc file
  * log1p: Use unary_decl instead of custom inc file
  * lgamma: Use unary_decl instead of custom inc file
  * exp2: Use unary_decl instead of custom inc file
  * cospi: Use unary_decl instead of custom inc file
  * cosh: Use unary_decl instead of custom inc file
  * cos: Use unary_decl instead of custom inc file
  * cbrt: Use unary_decl instead of custom inc file
  * atanpi: Use unary_decl instead of custom inc file
  * atanh: Use unary_decl instead of custom inc file
  * atan: Use unary_decl instead of custom inc file
  * asinpi: Use unary_decl instead of custom inc file
  * asinh: Use unary_dec instead of custom inc file
  * asin: Use unary_decl instead of custom inc file
  * acospi: Use unary_decl instead of custom inc file
  * acosh: Use unary_decl instead of custom inc file
  * acos: Use unary_decl instead of custom inc file
  * math: Implement native_log10
  * amdgpu/math: Don't use llvm instrinsic for native_log
  * shared: Implement aligned vector stores (vstorea_half)
  * shared: Implement aligned vector loads (vloada_half)
  * amdgcn: Add missing datalayout info to .ll files
  * r600: Add missing datalayout to .ll files
  * travis: enable checks of nvptx libraries
  * travis: Enable external function call checks on llvm-{4,5}
  * Make image builtins r600/llvm-3.9 only
  * Implement mem_fence on ptx
  * Make ptx barrier work irrespective of the cl_mem_fence_flags
  * travis: Make sure we report failure even if only earlier checked files fail
  * check_external_calls.sh: Print number of calls in tested file.
  * ptx: Use __clc_nextafter to implement nextafter
  * Do not include clc_nextafter header globally
  * math/nextafter: Use custom declaration inc file
  * math/binary_decl.inc: Do not declare mixed float/double functions
  * ldexp: Fix double precision function return type
  * configure: Fix handling of directories with compats only source lists
  * Add vload_half helpers for ptx
  * Add vstore_half helpers for ptx
  * integer/sub_sat: Use clang builtin instead of llvm asm
  * integer/add_sat: Use clang builtin instead of llvm asm
  * integer/clz: Use clang builtin instead of llvm asm
  * Let get_work_dim take exactly 0 arguments
  * Do no circularly define NULL
  * Fix amdgcn-amdhsa on llvm-3.9
  * travis: Check built libraries on llvm-3.9
  * Add script to check for unresolved function calls
  * geometric: geometric functions are only supported for vector lengths <=4
  * travis: add build using llvm-3.9
  * Restore support for llvm-3.9
  * Add missing HAVE_LLVM define to fix build with latest llvm
  * Rework atomic ops to use clang builtins rather than llvm asm
  * prepare_builtins: Fix compile breakage with older LLVM
  * [Support] Rename tool_output_file to ToolOutputFile, NFC
- Use python3 for building
* Thu Sep 21 2017 jimmy@boombatower.com
- Update to version 0.2.0+git.20170920:
  * generic: add missing get_work_dim include
  * add __kernel_exec macros
  * configure.py: Make python3 friendly
  * configure.py: Drop explicit import of int builtin
  * amdgcn: Implement {read_,write_,}mem_fence builtin
  * amdgcn: rewrite barrier() using fence and clang __builtin_amdgcn_s_barrier
  * Add halfN types and enable fp16 when generating builtin declarations
  * relational: Implement shuffle builtin
  * relational: Implement shuffle2 builtin
  * Fixup clc.h comment
  * r600: Cleanup barrier implementation.
  * amdgcn,waitcnt: Add datalayout info
  * configure.py: Simplify compatibility sources
  * vstore: Cleanup and add vstore(half)
  * Implement vload_half{,n} and vload(half)
  * integer: Add popcount implementation using ctpop intrinsic
  * Add native_recip(x) as ((1)/(x))
  * Add travis CI configuration file
  * Implement cl_khr_int64_base_atomics builtins
  * Implement cl_khr_int64_extended_atomics builtins
* Wed Apr 12 2017 jimmy@boombatower.com
- Update rpmlintrc to include both lib dir .pc files.
* Mon Apr 10 2017 jimmy@boombatower.com
- Update to version 0.2.0+git.20170225:
  * Fix build since llvm r286566 and require at least llvm 4.0
  * Fix build since r286752.
  * math: Add expm1 builtin function
  * math: Add logb builtin
  * math: Add native_rsqrt builtin function
  * Add the correct prefixes to the cl_khr_fp64 pragma
  * Move BufferPtr into the block where it it being used
  * math: Add native_tan as wrapper to tan
  * .gitignore: Ignore amdgcn-mesa object directory
  * math: Implement sinh function
* Sun Sep 25 2016 mpluskal@suse.com
- Update to version 0.2.0+git.20160921:
  * Avoid ambiguity in calling atom_add functions.
  * Replace nextafter implementation
  * Add ADDR_SPACE parameter to _CLC_V_V_VP_VECTORIZE
  * math: Implement lgamma_r
  * math: Implement lgamma
  * math: Implement tgamma
  * amdgcn-amdhsa: Add get_global_size() implementation
  * amdgcn-amdhsa: Add get_num_groups implementation
  * configure: Add amdgcn-mesa-mesa3d target
  * Provide vstore_half helper to workaround clc restrictions
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 0.2.0+git.20160209:
  * integer: remove explicit casts from _MIN definitions
  * AMDGPU: Add alias for tonga
  * AMDGPU: Add aliases for all VI targets
  * Add _CLC_V_V_VP_VECTORIZE macro
  * Implement modf math builtin
  * math: Add frexp ported from amd-builtins
  * math: Fix log2 vectorization on non-fp64 hw
  * configure: Introduce per device defines
  * configure: Remove cl_khr_fp64 for device that don't support doubles
  * configure: Remove llvm 3.6 defines
* Thu Dec 17 2015 coolo@suse.com
- fix license according to legal team
* Thu Dec 17 2015 sndirsch@suse.com
- modify license to 'BSD-3-Clause or MIT'
- added LICENSE.TXT file to %%doc
* Wed Dec  9 2015 mpluskal@suse.com
- Remove unnecessary ldconfig calls
- Rename rpmlintrc to libclc-rpmlintrc
- Minor spec file cleanup
* Tue Dec  8 2015 sndirsch@suse.com
- used BSD-3-Clause instead of BSD-2-Clause in order to make our
  legal team happy
* Mon Dec  7 2015 sndirsch@suse.com
- added rpmlintrc as source to specfile
* Wed Dec  2 2015 jimmy@boombatower.com
- Remove devel package in favor of main package since libclc is
  unusable without the header files used to compile OpenCL
  applications against.
* Mon Nov 30 2015 jimmy@boombatower.com
- Merge home:X0F:HSF spec changes.
- Set _service file to static revisions in lieu of tags.
- Major cleanup of spec file.
- Apply spec-cleaner.
* Fri Feb  3 2012 pontostroy@gmail.com
- initial package
